@@ -27,35 +27,35 @@
 #' \code{conductor_samp = c("Low","Medium/Normal","High","Default")}.
 #' See page 161, table 199 and 201 in CNAIM (2021).
 #' @inheritParams current_health
-#' @return Numeric. Current probability of failure
-#' per annum per kilometer.
+#' @return DataFrame Current probability of failure
+#' per annum per kilometer along with current health score.
 #' @source DNO Common Network Asset Indices Methodology (CNAIM),
 #' Health & Criticality - Version 2.1, 2021:
 #' \url{https://www.ofgem.gov.uk/sites/default/files/docs/2021/04/dno_common_network_asset_indices_methodology_v2.1_final_01-04-2021.pdf}
 #' @export
 #' @examples
 #' # Current annual probability of failure for EHV Swicthgear
-# pof_ehv_fittings(
-# ehv_asset_category = "33kV Fittings",
-# placement = "Default",
-# altitude_m = "Default",
-# distance_from_coast_km = "Default",
-# corrosion_category_index = "Default",
-# age = 10,
-# observed_condition_inputs =
-# list("insulator_elec_cond" =
-# list("Condition Criteria: Observed Condition" = "Default"),
-# "insulator_mech_cond" =
-# list("Condition Criteria: Observed Condition" = "Default"),
-# "conductor_fitting_cond" =
-# list("Condition Criteria: Observed Condition" = "Default"),
-# "tower_fitting_cond" =
-# list("Condition Criteria: Observed Condition" = "Default")),
-# measured_condition_inputs =
-# list("thermal_imaging" =
-# list("Condition Criteria: Thermal Imaging Result" = "Default"),
-# "ductor_test" = list("Condition Criteria: Ductor Test Result" = "Default")),
-# reliability_factor = "Default")
+#' pof_ehv_fittings(
+#' ehv_asset_category = "33kV Fittings",
+#' placement = "Default",
+#' altitude_m = "Default",
+#' distance_from_coast_km = "Default",
+#' corrosion_category_index = "Default",
+#' age = 10,
+#' observed_condition_inputs =
+#' list("insulator_elec_cond" =
+#' list("Condition Criteria: Observed Condition" = "Default"),
+#' "insulator_mech_cond" =
+#' list("Condition Criteria: Observed Condition" = "Default"),
+#' "conductor_fitting_cond" =
+#' list("Condition Criteria: Observed Condition" = "Default"),
+#' "tower_fitting_cond" =
+#' list("Condition Criteria: Observed Condition" = "Default")),
+#' measured_condition_inputs =
+#' list("thermal_imaging" =
+#' list("Condition Criteria: Thermal Imaging Result" = "Default"),
+#' "ductor_test" = list("Condition Criteria: Ductor Test Result" = "Default")),
+#' reliability_factor = "Default")
 pof_ehv_fittings <-
   function(ehv_asset_category = "33kV Fittings",
            placement = "Default",
@@ -188,6 +188,6 @@ pof_ehv_fittings <-
          (((c * current_health_score)^3) / factorial(3)))
 
 
-    return(probability_of_failure)
+    return(data.frame(pof = probability_of_failure, chs = current_health_score))
   }
 
